@@ -23,6 +23,9 @@ class _StoreTruth(IDeclarativeOption):
             return None
         return bool(o)
 
+    def handle_input(self, arg_content: str) -> Any:
+        return
+
 class StoreTrueDO(_StoreTruth):
     ACTION: str = 'store_true'
     DEFAULT: bool = False
